<template>
  <div id="orders">
    <transition name="expand">
      <div
        v-show="showMessage"
        class="success">
        <p v-if="shop.isShipper">Your delivery of<span> 1 {{ updatedOrderName }}</span> has been marked as delivered.</p>
        <p v-else-if="shop.shipperName.includes('Towne Hall')">
          Your order for <span> 1 {{ updatedOrderName }}</span> has been marked as complete, now please take to delivery person in <span>{{ shop.shipperName }}</span> for final delivery.
        </p>
        <p v-else>
          Your order for <span> 1 {{ updatedOrderName }}</span> has been marked as complete, and notification has been sent to <span>{{ shop.shipperName }}</span> for pick up.
        </p>
      </div>
    </transition>
    <h1 v-if="shop.isShipper">Deliveries in Process</h1>
    <h1 v-else>Orders in Process</h1>
    <table
      id="inProgressOrdersTable"
      border="0"
      width="">
      <thead>
        <tr>
          <template v-if="shop.isShipper">
            <th>Product</th>
            <th>Deliver To</th>
            <th>Pick Up Order At</th>
            <th>Action</th>
          </template>
          <template v-else>
            <th>Order Number</th>
            <th>For</th>
            <th v-if="shop.canonical_name === 'warehouse'">Engraving</th>
            <th v-else>&nbsp;</th>
            <th style="text-align: center;">Action</th>
          </template>
        </tr>
      </thead>
      <tbody
        v-for="order in orders"
        :key="order.order_id"
        class="orders">
        <tr
          v-if="order.status === 'in_progress'" >
          <td>{{ order.order_id }}</td>
          <td>{{ order.account.name }} <span> at {{ order.destination_shop_name }}</span></td>
          <td v-if="shop.canonical_name === 'warehouse'">{{ order.personalization }}</td>
          <td v-else/>
          <td><a
            style="margin-right: 12px;"
            class="button updateStatus"
            @click="markCompleted(order)">Mark Complete</a></td>
        </tr>
        <tr v-if="order.status === 'completed' && shop.isShipper">
          <td>{{ order.name }}</td>
          <td>{{ order.account.name }} <span> at {{ order.destination_shop_name }}</span></td>
          <td>{{ order.originating_shop }}</td>
          <td><a
            class="button updateStatus"
            @click="markDelivered(order)">Mark Delivered</a></td>
        </tr>
      </tbody>
    </table>
    <h1 v-if="shop.isShipper">Completed Deliveries</h1>
    <h1 v-else>Completed Orders</h1>
    <table
      id="completedOrdersTable"
      border="0"
      width="">
      <thead>
        <tr>
          <template v-if="shop.isShipper">
            <th>Product</th>
            <th>Delivered To</th>
          </template>
          <template v-else>
            <th>Order Number</th>
            <th>For</th>
          </template>
        </tr>
      </thead>
      <tbody
        v-for="order in orders"
        :key="order.order_id"
        class="orders">
        <tr
          v-if="order.status === 'completed' && !shop.isShipper">
          <td>{{ order.order_id }}</td>
          <td style="text-align: left;">{{ order.account.name }} <span> at {{ order.destination_shop_name }}</span></td>
        </tr>
        <tr v-if="order.status === 'delivered' && shop.isShipper">
          <td>{{ order.name }}</td>
          <td style="text-align: left;">{{ order.account.name }} <span> at {{ order.destination_shop_name }}</span></td>
        </tr>
      </tbody>
    </table>

  </div>
</template>

<script>
export default {
  props: {
    shop:Object,
    orders:Array
  },
  data(){
    return{
      showMessage:false,
      updatedOrderName:String
    };
  },
  methods:{
    markCompleted(orderObject){
      const order = orderObject;
      order.status = "completed";
      order.originating_shop = this.shop.pretty_name;
      this.updatedOrderName = order.name;
      app.api.Put( "/orders/" + order.order_id, order)
        .then( Response => {
          this.showMessage = true;
          // emit up to trigger refresh
          this.$emit("product-changed");
          setTimeout(() => {
            this.showMessage = false;
          }, 5000);
        })
      .catch( x => app.Message( x.error, "error" ) );
    },
    markDelivered(orderObject){
      const order = orderObject;
      order.status = "delivered";
      this.updatedOrderName = order.name;
      app.api.Put( "/orders/" + order.order_id, order)
        .then( Response => {
          this.showMessage = true;
          // emit up to trigger refresh
          this.$emit("order-changed");
          setTimeout(() => {
            this.showMessage = false;
          }, 5000);
        });
    }
  }
};
</script>

<style>
/* always present */
.expand-transition {
  transition: all .3s ease;
  height: 30px;
  padding: 10px;
  background-color: #eee;
  overflow: hidden;
}
/* .expand-enter defines the starting state for entering */
/* .expand-leave defines the ending state for leaving */
.expand-enter, .expand-leave {
  height: 0;
  padding: 0 10px;
  opacity: 0;
}
</style>


